% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: theory.pl,v $
%%  $Revision: 1.11 $
%%      $Date: 2007/03/05 11:26:29 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- (environ('TRALE_UNICODE', true);
    format(user_error,"~n~n**ERROR: Please start trale with the option `-u' to enable unicode support, which is needed for this grammar.~n~n~n",[]),
    abort).

% für [incr TSDB()]
grammar_version('Lehrbuchgrammatik Kapitel 19').


% feature hiding and ordering
hidden_feat(dtrs).      % hide the dtrs attribute (shown by tree)

% Die sind in den Bäumen enthalten, deshalb werden sie hier ausgeblendet.
hidden_feat(non_head_dtrs).
hidden_feat(head_dtr).


% Binäres Merkmal, das aus Effizenzgründen verwendet wird.
% Sieht nicht gut aus in Demos ... =;-)
hidden_feat(trace).


>>> phon.        % phon shall be shown first
phon <<< synsem.
synsem <<< qstore.
qstore <<< head_dtr.

head <<< subcat.

loc <<< nonloc.
nonloc <<< lex.
%<<<(lex, max_).

% use ghostview for drawing signatures
graphviz_option(ps,gv).
%graphviz_option(svg,squiggle).

% Load phonology and tree output

:- [trale_home(tree_extensions)].


:- chart_display.

:- nochart_debug.  % this helps if somebody interrupted during chart debugging and the
                   % flag is still set to 'on'.

:- german.

:- notcl_warnings.  % on = output of warnings in a TCL window, off = output to console

:- hrp.  % use grisu for rules

%:- nofs. % do not print feature structures after parsing

root_symbol(@root).
decl_symbol(@decl).
que_symbol(@interrog).

% load tokenization rules for parsing ordinary strings and atoms
:- ['../Gemeinsames/tokenization'].

% specify signature file
signature(signature).

% load lexicon
:- [lexicon].
%:- ['lexicon-test'].


% load lexical macros
:- [le_macros].
:- [flex_macros].


% load lexical macros for the copula
% :- [copula].


% load suffixes for inflection
:- [suffixes].


% load lexical rules
:- [lexrules].


% load lexical rule for multiple frontings
% :- ['mehrfache-vorfeldbesetzung'].

% load phrase structure rules
:- [rules].

:- [oberfeldumstellung].

% load phrase structure macros
:- [syntax].



% load some constraints that are not linguistically necessary,
% but good for performance
:- [speed].

% load relational constraints for rules
:- [constraints].

% load a test sequence
:- [test_items].

% load a sequence that is executed after the grammar is loaded
:- ['../Gemeinsames/common.pl'].


examples(['  der das Buch lesende  Mann',
          '  der das Buch lesen wollende Mann',
          '  das lesbare Buch',
          '* das gelesen habbare Buch',
          '  die angelachte Frau',
          '  die loslachende Frau',
          '  die den Mann anlachende Frau',
          '  die anlachbare Frau',
          '  das Herumgerenne']).


:- abolish(morph/3).

% % Das ist eine Kopie des Codes aus ale.pl
% % + einer Zeile zur Ausgabe des aktuell erzeugten Wortes.
% % Das ist zum Debuggen und wegen der langen Lexikonkompilierungszeit sinnvoll.

morph(Morphs,WordIn,WordOut):-  % need to instantiate Word even if
  name(WordIn,CodesIn),         %  X becomes X - do we want this?
  make_char_list(CodesIn,CharsIn), 
  morph_chars(Morphs,CharsIn,CharsOut),
  make_char_list(CodesOut,CharsOut),
  name(WordOut,CodesOut),
  format(user_error,"~w~n",[WordOut]),
%  write(user_error,'.'),flush_output(user_error),
  true.
